@@ -27,7 +27,7 @@
 #include <sys/types.h>
 #include <glib.h>
 
-#include "common/gkr-buffer.h"
+#include "egg/egg-buffer.h"
 
 #include "keyrings/gkr-keyring.h"
 #include "keyrings/gkr-keyring-item.h"
@@ -40,17 +40,19 @@ typedef struct {
 	GnomeKeyringApplicationRef *app_ref;
 } GkrKeyringRequest;	
 
-typedef gboolean (*GkrDaemonOperation) (GkrBuffer *packet, GkrBuffer *result,
+typedef gboolean (*GkrDaemonOperation) (EggBuffer *packet, EggBuffer *result,
                                         GkrKeyringRequest *req);
 
 extern GkrDaemonOperation keyring_ops[];
 
+void           gkr_daemon_quit (void);
+
+gboolean       gkr_daemon_complete_initialization (void);
+
 gboolean       gkr_daemon_io_create_master_socket (void);
+
 const gchar*   gkr_daemon_io_get_socket_path      (void);
 
-/* Dbus Initialization/Cleanup */
-#ifdef WITH_DBUS
-void gkr_daemon_dbus_setup (GMainLoop *loop);
-#endif 
+void           gkr_daemon_dbus_setup              (void);
 
 #endif /* GNOME_KEYRING_DAEMON_H */
