@@ -126,7 +126,7 @@ test_C_Initialize (CK_VOID_PTR pInitArgs)
 	/* Our token object */
 	attrs = gp11_attributes_newv (CKA_CLASS, GP11_ULONG, CKO_DATA,
 	                              CKA_LABEL, GP11_STRING, "TEST LABEL",
-	                              -1);
+	                              GP11_INVALID);
 	g_hash_table_insert (the_objects, GUINT_TO_POINTER (2), attrs);
 	
 	/* Private capitalize key */
@@ -136,7 +136,7 @@ test_C_Initialize (CK_VOID_PTR pInitArgs)
 	                              CKA_ALLOWED_MECHANISMS, sizeof (value), &value,
 	                              CKA_DECRYPT, GP11_BOOLEAN, TRUE,
 	                              CKA_PRIVATE, GP11_BOOLEAN, TRUE,
-	                              -1);
+	                              GP11_INVALID);
 	g_hash_table_insert (the_objects, GUINT_TO_POINTER (PRIVATE_KEY_CAPITALIZE), attrs);
 
 	/* Public capitalize key */
@@ -146,7 +146,7 @@ test_C_Initialize (CK_VOID_PTR pInitArgs)
 	                              CKA_ALLOWED_MECHANISMS, sizeof (value), &value,
 	                              CKA_ENCRYPT, GP11_BOOLEAN, TRUE,
 	                              CKA_PRIVATE, GP11_BOOLEAN, FALSE,
-	                              -1);
+	                              GP11_INVALID);
 	g_hash_table_insert (the_objects, GUINT_TO_POINTER (PUBLIC_KEY_CAPITALIZE), attrs);
 
 	/* Private prefix key */
@@ -157,7 +157,7 @@ test_C_Initialize (CK_VOID_PTR pInitArgs)
 	                              CKA_SIGN, GP11_BOOLEAN, TRUE,
 	                              CKA_PRIVATE, GP11_BOOLEAN, TRUE,
 	                              CKA_ALWAYS_AUTHENTICATE, GP11_BOOLEAN, TRUE,
-	                              -1);
+	                              GP11_INVALID);
 	g_hash_table_insert (the_objects, GUINT_TO_POINTER (PRIVATE_KEY_PREFIX), attrs);
 
 	/* Private prefix key */
@@ -167,7 +167,7 @@ test_C_Initialize (CK_VOID_PTR pInitArgs)
 	                              CKA_ALLOWED_MECHANISMS, sizeof (value), &value,
 	                              CKA_VERIFY, GP11_BOOLEAN, TRUE,
 	                              CKA_PRIVATE, GP11_BOOLEAN, FALSE,
-	                              -1);
+	                              GP11_INVALID);
 	g_hash_table_insert (the_objects, GUINT_TO_POINTER (PUBLIC_KEY_PREFIX), attrs);
 	
 	initialized = TRUE;
@@ -191,7 +191,7 @@ test_C_Finalize (CK_VOID_PTR pReserved)
 	return CKR_OK;
 }
 
-const static CK_INFO TEST_INFO = {
+static const CK_INFO TEST_INFO = {
 	{ CRYPTOKI_VERSION_MAJOR, CRYPTOKI_VERSION_MINOR },
 	"TEST MANUFACTURER              ",
 	0, 
@@ -251,7 +251,7 @@ test_C_GetSlotList (CK_BBOOL tokenPresent, CK_SLOT_ID_PTR pSlotList, CK_ULONG_PT
 	return CKR_OK;
 }
 
-const static CK_SLOT_INFO TEST_INFO_ONE = {
+static const CK_SLOT_INFO TEST_INFO_ONE = {
 	"TEST SLOT                                                       ",
 	"TEST MANUFACTURER              ",
 	CKF_TOKEN_PRESENT | CKF_REMOVABLE_DEVICE,
@@ -259,7 +259,7 @@ const static CK_SLOT_INFO TEST_INFO_ONE = {
 	{ 65, 165 },
 };
 
-const static CK_SLOT_INFO TEST_INFO_TWO = {
+static const CK_SLOT_INFO TEST_INFO_TWO = {
 	"TEST SLOT                                                       ",
 	"TEST MANUFACTURER              ",
 	CKF_REMOVABLE_DEVICE,
@@ -284,7 +284,7 @@ test_C_GetSlotInfo (CK_SLOT_ID slotID, CK_SLOT_INFO_PTR pInfo)
 	}
 }
 
-const static CK_TOKEN_INFO TEST_TOKEN_ONE = {
+static const CK_TOKEN_INFO TEST_TOKEN_ONE = {
 	"TEST LABEL                      ",
 	"TEST MANUFACTURER               ",
 	"TEST MODEL      ",
