@@ -69,10 +69,10 @@ GckManager*              gck_session_get_manager                        (GckSess
 
 gboolean                 gck_session_get_read_only                      (GckSession *self);
 
-gboolean                 gck_session_get_logged_in                      (GckSession *self);
+gulong                   gck_session_get_logged_in                      (GckSession *self);
 
 void                     gck_session_set_logged_in                      (GckSession *self,
-                                                                         gboolean logged_in);
+                                                                         gulong logged_in);
 
 CK_RV                    gck_session_lookup_readable_object             (GckSession *self, 
                                                                          CK_OBJECT_HANDLE handle, 
@@ -97,16 +97,6 @@ CK_RV                    gck_session_C_CancelFunction                   (GckSess
 CK_RV                    gck_session_C_GetSessionInfo                   (GckSession* self, 
                                                                          CK_SESSION_INFO_PTR info);
 
-CK_RV                    gck_session_C_InitPIN                          (GckSession* self, 
-                                                                         CK_UTF8CHAR_PTR pin,
-                                                                         CK_ULONG pin_len);
-
-CK_RV                    gck_session_C_SetPIN                           (GckSession* self, 
-                                                                         CK_UTF8CHAR_PTR old_pin,
-                                                                         CK_ULONG old_pin_len, 
-                                                                         CK_UTF8CHAR_PTR new_pin, 
-                                                                         CK_ULONG new_pin_len);
-
 CK_RV                    gck_session_C_GetOperationState                (GckSession* self, 
                                                                          CK_BYTE_PTR operation_state,
                                                                          CK_ULONG_PTR operation_state_len);
